@@ -20,7 +20,7 @@ from typing import (
     get_type_hints,
 )
 
-from tango.common._det_hash import CustomDetHash
+from tango.common.det_hash import CustomDetHash
 from tango.common.exceptions import ConfigurationError
 from tango.common.lazy import Lazy
 from tango.common.params import Params
