@@ -75,15 +75,17 @@ class TangoTestCase:
 
             overrides = json.dumps(overrides)
 
-        return _run(
+        run_name = _run(
             TangoGlobalSettings(),
             str(config),
-            workspace_dir=str(self.TEST_DIR / "workspace"),
+            workspace_url="local://" + str(self.TEST_DIR / "workspace"),
             overrides=overrides,
             include_package=include_package,
             start_server=False,
         )
 
+        return self.TEST_DIR / "workspace" / "runs" / run_name
+
 
 @contextmanager
 def run_experiment(
@@ -105,3 +107,17 @@ def run_experiment(
     finally:
         test_case.teardown_method()
         teardown_logging()
+
+
+def requires_gpus(test_method):
+    """
+    Decorator to indicate that a test requires multiple GPU devices.
+    """
+    import pytest
+    import torch
+
+    return pytest.mark.gpu(
+        pytest.mark.skipif(torch.cuda.device_count() < 2, reason="2 or more GPUs required.")(
+            test_method
+        )
+    )
