@@ -5,7 +5,6 @@ import importlib
 import json
 import logging
 import lzma
-import mmap
 from abc import abstractmethod
 from os import PathLike
 from pathlib import Path
@@ -19,18 +18,20 @@ from typing import (
     Iterator,
     List,
     Optional,
+    Sequence,
     TypeVar,
     Union,
     cast,
 )
 
 import dill
-import xxhash
 
+from tango.common import DatasetDict, filename_is_safe
 from tango.common.aliases import PathOrStr
 from tango.common.exceptions import ConfigurationError
 from tango.common.logging import TangoLogger
 from tango.common.registrable import Registrable
+from tango.common.sequences import SqliteSparseSequence
 
 T = TypeVar("T")
 
@@ -62,32 +63,6 @@ class Format(Registrable, Generic[T]):
         """Reads an artifact from the directory at ``dir`` and returns it."""
         raise NotImplementedError()
 
-    @abstractmethod
-    def checksum(self, dir: PathOrStr) -> str:
-        """
-        Produces a checksum of the serialized artifact.
-
-        Should raise :class:`FileNotFoundError` if the artifact can't be found.
-        """
-        raise NotImplementedError()
-
-    @staticmethod
-    def _checksum_artifact(path: PathOrStr) -> str:
-        """
-        A helper method that can be used to compute the checksum of an artifact.
-
-        This can make implementing :meth:`checksum()` easier.
-        """
-        filepath = Path(path)
-        if not filepath.is_file():
-            raise FileNotFoundError(str(filepath))
-
-        h = xxhash.xxh128()
-        with filepath.open("rb") as f:
-            with mmap.mmap(f.fileno(), 0, prot=mmap.PROT_READ) as m:
-                h.update(m)
-        return h.hexdigest()
-
 
 _OPEN_FUNCTIONS: Dict[Optional[str], Callable[[PathLike, str], IO]] = {
     None: open,
@@ -96,10 +71,10 @@ _OPEN_FUNCTIONS: Dict[Optional[str], Callable[[PathLike, str], IO]] = {
     "null": open,
     "gz": gzip.open,  # type: ignore
     "gzip": gzip.open,  # type: ignore
-    "bz": bz2.open,
-    "bz2": bz2.open,
-    "bzip": bz2.open,
-    "bzip2": bz2.open,
+    "bz": bz2.open,  # type: ignore
+    "bz2": bz2.open,  # type: ignore
+    "bzip": bz2.open,  # type: ignore
+    "bzip2": bz2.open,  # type: ignore
     "lzma": lzma.open,
 }
 
@@ -172,17 +147,13 @@ class DillFormat(Format[T], Generic[T]):
             else:
                 return unpickler.load()
 
-    def checksum(self, dir: PathOrStr) -> str:
-        path = self._get_artifact_path(dir)
-        return self._checksum_artifact(path)
-
     def _get_artifact_path(self, dir: PathOrStr) -> Path:
         return Path(dir) / ("data.dill" + _SUFFIXES[self.open])
 
 
 class DillFormatIterator(Iterator[T], Generic[T]):
     """
-    An ``Iterator`` class that is used so we can return an iterator from ``DillFormat.read()``.
+    An ``Iterator`` class that is used to return an iterator from :meth:`tango.format.DillFormat.read`.
     """
 
     def __init__(self, filename: PathOrStr):
@@ -219,7 +190,6 @@ class JsonFormat(Format[T], Generic[T]):
     .. tip::
         This format has special support for iterables. If you write an iterator, it will consume the
         iterator. If you read an iterator, it will read the iterator lazily.
-
     """
 
     VERSION = 2
@@ -311,21 +281,13 @@ class JsonFormat(Format[T], Generic[T]):
         else:
             raise RuntimeError("This should be impossible.")
 
-    def checksum(self, dir: PathOrStr) -> str:
-        iterator_filename = self._get_artifact_path(dir, iterator=True)
-        non_iterator_filename = self._get_artifact_path(dir, iterator=False)
-        if iterator_filename.exists():
-            return self._checksum_artifact(iterator_filename)
-        else:
-            return self._checksum_artifact(non_iterator_filename)
-
     def _get_artifact_path(self, dir: PathOrStr, iterator: bool = False) -> Path:
         return Path(dir) / (("data.jsonl" if iterator else "data.json") + _SUFFIXES[self.open])
 
 
 class JsonFormatIterator(Iterator[T], Generic[T]):
     """
-    An ``Iterator`` class that is used so we can return an iterator from ``JsonFormat.read()``.
+    An ``Iterator`` class that is used to return an iterator from :meth:`tango.format.JsonFormat.read`.
     """
 
     def __init__(self, filename: PathOrStr):
@@ -346,3 +308,200 @@ class JsonFormatIterator(Iterator[T], Generic[T]):
             self.f.close()
             self.f = None
             raise StopIteration()
+
+
+@Format.register("text")
+class TextFormat(Format[Union[str, Iterable[str]]]):
+    """This format writes the artifact as a single file in text format.
+    Optionally, it can compress the data. This is very flexible, but not always the fastest.
+
+    This format can only write strings, or iterable of strings.
+
+    .. tip::
+        This format has special support for iterables. If you write an iterator, it will consume the
+        iterator. If you read an iterator, it will read the iterator lazily.
+
+        Be aware that if your strings contain newlines, you will read out more strings than you wrote.
+        For this reason, it's often advisable to use :class:`JsonFormat` instead. With :class:`JsonFormat`,
+        all special characters are escaped, strings are quoted, but it's all still human-readable.
+    """
+
+    VERSION = 1
+
+    def __init__(self, compress: Optional[str] = None):
+        self.logger = cast(TangoLogger, logging.getLogger(self.__class__.__name__))
+        try:
+            self.open = _OPEN_FUNCTIONS[compress]
+        except KeyError:
+            raise ConfigurationError(f"The {compress} compression format does not exist.")
+
+    def write(self, artifact: Union[str, Iterable[str]], dir: PathOrStr):
+        if hasattr(artifact, "__next__"):
+            filename = self._get_artifact_path(dir, iterator=True)
+            with self.open(filename, "wt") as f:
+                for item in cast(Iterable, artifact):
+                    f.write(str(item))
+                    f.write("\n")
+        else:
+            filename = self._get_artifact_path(dir, iterator=False)
+            with self.open(filename, "wt") as f:
+                f.write(str(artifact))
+
+    def read(self, dir: PathOrStr) -> Union[str, Iterable[str]]:
+        iterator_filename = self._get_artifact_path(dir, iterator=True)
+        iterator_exists = iterator_filename.exists()
+        non_iterator_filename = self._get_artifact_path(dir, iterator=False)
+        non_iterator_exists = non_iterator_filename.exists()
+
+        if iterator_exists and non_iterator_exists:
+            self.logger.warning(
+                "Both %s and %s exist. Ignoring %s.",
+                iterator_filename,
+                non_iterator_filename,
+                iterator_filename,
+            )
+            iterator_exists = False
+
+        if not iterator_exists and not non_iterator_exists:
+            raise IOError("Attempting to read non-existing data from %s", dir)
+        if iterator_exists and not non_iterator_exists:
+            return TextFormatIterator(iterator_filename)  # type: ignore
+        elif not iterator_exists and non_iterator_exists:
+            with self.open(non_iterator_filename, "rt") as f:
+                return f.read()
+        else:
+            raise RuntimeError("This should be impossible.")
+
+    def _get_artifact_path(self, dir: PathOrStr, iterator: bool = False) -> Path:
+        return Path(dir) / (("texts.txt" if iterator else "text.txt") + _SUFFIXES[self.open])
+
+
+class TextFormatIterator(Iterator[str]):
+    """
+    An ``Iterator`` class that is used to return an iterator from :meth:`tango.format.TextFormat.read`.
+    """
+
+    def __init__(self, filename: PathOrStr):
+        self.f: Optional[IO[Any]] = _open_compressed(filename, "rt")
+
+    def __iter__(self) -> Iterator[str]:
+        return self
+
+    def __next__(self) -> str:
+        if self.f is None:
+            raise StopIteration()
+        try:
+            line = self.f.readline()
+            if len(line) <= 0:
+                raise EOFError()
+            return line
+        except EOFError:
+            self.f.close()
+            self.f = None
+            raise StopIteration()
+
+
+@Format.register("sqlite_sequence")
+class SqliteSequenceFormat(Format[Sequence[T]]):
+    VERSION = 3
+
+    FILENAME = "data.sqlite"
+
+    def write(self, artifact: Sequence[T], dir: Union[str, PathLike]):
+        dir = Path(dir)
+        try:
+            (dir / self.FILENAME).unlink()
+        except FileNotFoundError:
+            pass
+        if isinstance(artifact, SqliteSparseSequence):
+            artifact.copy_to(dir / self.FILENAME)
+        else:
+            sqlite = SqliteSparseSequence(dir / self.FILENAME)
+            sqlite.extend(artifact)
+
+    def read(self, dir: Union[str, PathLike]) -> Sequence[T]:
+        dir = Path(dir)
+        return SqliteSparseSequence(dir / self.FILENAME, read_only=True)
+
+
+@Format.register("sqlite")
+class SqliteDictFormat(Format[DatasetDict]):
+    """This format works specifically on results of type :class:`~tango.common.DatasetDict`. It writes those
+    datasets into Sqlite databases.
+
+    During reading, the advantage is that the dataset can be read lazily. Reading a result that is stored
+    in :class:`SqliteDictFormat` takes milliseconds. No actual reading takes place until you access individual
+    instances.
+
+    During writing, you have to take some care to take advantage of the same trick. Recall that
+    :class:`~tango.DatasetDict` is basically a map, mapping split names to lists of instances. If you ensure
+    that those lists of instances are of type :class:`~tango.common.sequences.SqliteSparseSequence`, then writing
+    the results in :class:`SqliteDictFormat` can in many cases be instantaneous.
+
+    Here is an example of the pattern to use to make writing fast:
+
+    .. code-block:: Python
+
+        @Step.register("my_step")
+        class MyStep(Step[DatasetDict]):
+
+            FORMAT: Format = SqliteDictFormat()
+            VERSION = "001"
+
+            def run(self, ...) -> DatasetDict:
+                result: Dict[str, Sequence] = {}
+                for split_name in my_list_of_splits:
+                    output_split = SqliteSparseSequence(self.work_dir / f"{split_name}.sqlite")
+                    for instance in instances:
+                        output_split.append(instance)
+                    result[split_name] = output_split
+
+                metadata = {}
+                return DatasetDict(result, metadata)
+
+    Observe how for each split, we create a :class:`~tango.common.sequences.SqliteSparseSequence` in the step's
+    work directory (accessible with :meth:`~tango.step.Step.work_dir`). This has the added advantage that if the
+    step fails and you have to re-run it, the previous results that were already written to the
+    :class:`~tango.common.sequences.SqliteSparseSequence` are still there. You could replace the inner ``for``
+    loop like this to take advantage:
+
+    .. code-block:: Python
+
+        output_split = SqliteSparseSequence(self.work_dir / f"{split_name}.sqlite")
+        for instance in instances[len(output_split):]:      # <-- here is the difference
+            output_split.append(instance)
+        result[split_name] = output_split
+
+    This works because when you re-run the step, the work directory will still be there, so ``output_split`` is
+    not empty when you open it.
+    """
+
+    VERSION = 3
+
+    def write(self, artifact: DatasetDict, dir: Union[str, PathLike]):
+        dir = Path(dir)
+        with gzip.open(dir / "metadata.dill.gz", "wb") as f:
+            dill.dump(artifact.metadata, f)
+        for split_name, split in artifact.splits.items():
+            filename = f"{split_name}.sqlite"
+            if not filename_is_safe(filename):
+                raise ValueError(f"{split_name} is not a valid name for a split.")
+            try:
+                (dir / filename).unlink()
+            except FileNotFoundError:
+                pass
+            if isinstance(split, SqliteSparseSequence):
+                split.copy_to(dir / filename)
+            else:
+                sqlite = SqliteSparseSequence(dir / filename)
+                sqlite.extend(split)
+
+    def read(self, dir: Union[str, PathLike]) -> DatasetDict:
+        dir = Path(dir)
+        with gzip.open(dir / "metadata.dill.gz", "rb") as f:
+            metadata = dill.load(f)
+        splits = {
+            filename.stem: SqliteSparseSequence(filename, read_only=True)
+            for filename in dir.glob("*.sqlite")
+        }
+        return DatasetDict(metadata=metadata, splits=splits)
