@@ -1,8 +1,10 @@
 import logging
 from typing import Any, Dict, Iterator, List, Mapping, Set
 
+from tango.common import PathOrStr
 from tango.common.exceptions import ConfigurationError
 from tango.common.params import Params
+from tango.common.util import import_extra_module
 from tango.step import Step
 
 logger = logging.getLogger(__name__)
@@ -167,3 +169,10 @@ class StepGraph(Mapping[str, Step]):
             else:
                 steps_not_run.append(step)
         return result
+
+    @classmethod
+    def from_file(cls, filename: PathOrStr):
+        params = Params.from_file(filename)
+        for package_name in params.pop("include_package", []):
+            import_extra_module(package_name)
+        return StepGraph(params.pop("steps", keep_as_dict=True))
